@@ -12,7 +12,7 @@ class Task(NamespacedResource):
 
     def __init__(
         self,
-        steps: Optional[List[Dict[str, Any]]] = None,
+        steps: List[Dict[str, Any]],
         description: Optional[str] = None,
         params: Optional[List[Dict[str, str]]] = None,
         workspaces: Optional[List[Dict[str, Any]]] = None,
@@ -35,7 +35,9 @@ class Task(NamespacedResource):
             step_template (Optional[Dict[str, Any]]): Specifies a Container step definition to use as the basis for all Steps in the Task.
             sidecars (Optional[List[Dict[str, Any]]]): Specifies Sidecar containers to run alongside the Steps in the Task.
         """
-        super().__init__(**kwargs)
+        super().__init__(
+            **kwargs,
+        )
         self.steps = steps
         self.description = description
         self.params = params
@@ -47,7 +49,7 @@ class Task(NamespacedResource):
 
     def to_dict(self) -> None:
         super().to_dict()
-        if not self.kind_dict and not self.yaml_file:
+        if not self.yaml_file:
             if not self.steps:
                 raise MissingRequiredArgumentError(argument="steps")
             self.res["spec"] = {}
